@@ -96,59 +96,43 @@ LIST
   end
 
 
-  def test_find
-    list = PublicSuffix::List.parse(<<LIST)
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+  def test_find_iana
+    list = build_test_list
 
-// ===BEGIN ICANN DOMAINS===
-
-// com
-com
-
-// uk
-*.uk
-*.sch.uk
-!bl.uk
-!british-library.uk
-
-// io
-io
-
-// ===END ICANN DOMAINS===
-// ===BEGIN PRIVATE DOMAINS===
-
-// Google, Inc.
-blogspot.com
-
-// ===END PRIVATE DOMAINS===
-LIST
-
-    # match IANA
     assert_equal PublicSuffix::Rule.factory("com"), list.find("example.com")
     assert_equal PublicSuffix::Rule.factory("com"), list.find("foo.example.com")
+  end
+
+  def test_find_wildcard
+    list = build_test_list
 
-    # match wildcard
     assert_equal PublicSuffix::Rule.factory("*.uk"), list.find("example.uk")
     assert_equal PublicSuffix::Rule.factory("*.uk"), list.find("example.co.uk")
     assert_equal PublicSuffix::Rule.factory("*.uk"), list.find("foo.example.co.uk")
+  end
+
+  def test_find_exception
+    list = build_test_list
 
-    # match exception
     assert_equal PublicSuffix::Rule.factory("!british-library.uk"), list.find("british-library.uk")
     assert_equal PublicSuffix::Rule.factory("!british-library.uk"), list.find("foo.british-library.uk")
+  end
+
+  def test_find_default
+    list = build_test_list
 
-    # match default rule
     assert_equal PublicSuffix::Rule.factory("*"), list.find("test")
     assert_equal PublicSuffix::Rule.factory("*"), list.find("example.test")
     assert_equal PublicSuffix::Rule.factory("*"), list.find("foo.example.test")
+  end
+
+  def test_find_private
+    list = build_test_list
 
-    # match private
     assert_equal PublicSuffix::Rule.factory("blogspot.com", private: true), list.find("blogspot.com")
     assert_equal PublicSuffix::Rule.factory("blogspot.com", private: true), list.find("foo.blogspot.com")
   end
 
-
   def test_select
     assert_equal 2, list.send(:select, "british-library.uk").size
   end
@@ -177,7 +161,6 @@ LIST
     assert_equal list.send(:select, "foo.example.io", ignore_private: true), [r1]
   end
 
-
   def test_self_default_getter
     PublicSuffix::List.default = nil
 
@@ -232,9 +215,38 @@ LIST
     assert list.find("blogspot.com").private
   end
 
-
   private
 
+  def build_test_list
+    PublicSuffix::List.parse(<<LIST)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at https://mozilla.org/MPL/2.0/.
+
+// ===BEGIN ICANN DOMAINS===
+
+// com
+com
+
+// uk
+*.uk
+*.sch.uk
+!bl.uk
+!british-library.uk
+
+// io
+io
+
+// ===END ICANN DOMAINS===
+// ===BEGIN PRIVATE DOMAINS===
+
+// Google, Inc.
+blogspot.com
+
+// ===END PRIVATE DOMAINS===
+LIST
+  end
+
   def list
     @_list ||= PublicSuffix::List.parse(<<LIST)
 // com : http://en.wikipedia.org/wiki/.com
